@@ -1,6 +1,7 @@
 # django imports
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
+from django.db.models import Q
 
 # portlets imports
 from portlets.models import PortletAssignment
@@ -23,11 +24,15 @@ def get_slots(obj):
         for pa in PortletAssignment.objects.filter(
             slot=slot, content_id=obj.id, content_type=ct.id):
             has_portlets = True
-            temp.append({
-                "pa_id" : pa.id,
-                "title" : pa.portlet.title,
-                "type" : portlet_types.get(pa.portlet.__class__.__name__.lower(), ""),
-            })
+
+            # Display only registered portlets
+            portlet_type = portlet_types.get(pa.portlet.__class__.__name__.lower())
+            if portlet_type:
+                temp.append({
+                    "pa_id" : pa.id,
+                    "title" : pa.portlet.title,
+                    "type" : portlet_types.get(pa.portlet.__class__.__name__.lower(), ""),
+                })
 
         items.append({
             "id"   : slot.id,
@@ -70,6 +75,16 @@ def has_portlets(slot, obj):
 
 def get_portlets(slot, obj):
     """Returns portlet objs for a given slot and obj (content object).
+    
+    **Parameters**
+    
+    slot
+        The slot for which the portlets should be returned. Must be a Slot 
+        instance.
+        
+    obj
+        The object for the portlets should be returned. Must be a Django model.
+        
     """
     ctype = ContentType.objects.get_for_model(obj)
     try:
@@ -95,19 +110,30 @@ def get_registered_portlets():
 
     return portlet_types
 
-def register_portlet(obj, name):
-    """Registers a portlet.
+def register_portlet(klass, name):
+    """Registers a portlet. Name and klass must both be unique.
+    
+    **Parameters**
+    
+    klass
+        The portlet's python class
+        
+    name
+        Then unique name under which the portlet is registered
     """
-    type = obj.__name__.lower()
-    try:
+    type = klass.__name__.lower()
+    if not PortletRegistration.objects.filter(Q(type=type) | Q(name=name)):
         PortletRegistration.objects.create(type=type, name=name)
-    except:
-        pass
 
-def unregister_portlet(obj):
-    """Unregisters portlet with given type
+def unregister_portlet(klass):
+    """Unregisters portlet the passed portlet.
+
+    **Parameters**
+    
+    klass
+        The portlet's python class
     """
-    type = obj.__name__.lower()
+    type = klass.__name__.lower()
     try:
         pr = PortletRegistration.objects.get(type=type)
     except PortletRegistration.DoesNotExist:
